@@ -5,41 +5,46 @@ use 5.004;
 use strict;
 use Test::Builder;
 
+
 # Can't use Carp because it might cause use_ok() to accidentally succeed
 # even though the module being used forgot to use Carp.  Yes, this
 # actually happened.
 sub _carp {
-    my ( $file, $line ) = ( caller(1) )[ 1, 2 ];
+    my($file, $line) = (caller(1))[1,2];
     warn @_, " at $file line $line\n";
 }
 
+
+
 require Exporter;
 use vars qw($VERSION @ISA @EXPORT %EXPORT_TAGS $TODO);
-$VERSION = '0.42';
-@ISA     = qw(Exporter);
-@EXPORT  = qw(ok use_ok require_ok
-  is isnt like unlike is_deeply
-  cmp_ok
-  skip todo todo_skip
-  pass fail
-  eq_array eq_hash eq_set
-  $TODO
-  plan
-  can_ok  isa_ok
-  diag
-);
+$VERSION = '0.40';
+@ISA    = qw(Exporter);
+@EXPORT = qw(ok use_ok require_ok
+             is isnt like unlike is_deeply
+             cmp_ok
+             skip todo todo_skip
+             pass fail
+             eq_array eq_hash eq_set
+             $TODO
+             plan
+             can_ok  isa_ok
+            );
 
 my $Test = Test::Builder->new;
 
+
 # 5.004's Exporter doesn't have export_to_level.
-sub _export_to_level {
-    my $pkg   = shift;
-    my $level = shift;
-    (undef) = shift;    # redundant arg
-    my $callpkg = caller($level);
-    $pkg->export( $callpkg, @_ );
+sub _export_to_level
+{
+      my $pkg = shift;
+      my $level = shift;
+      (undef) = shift;                  # redundant arg
+      my $callpkg = caller($level);
+      $pkg->export($callpkg, @_);
 }
 
+
 =head1 NAME
 
 Test::More - yet another framework for writing test scripts
@@ -61,9 +66,6 @@ Test::More - yet another framework for writing test scripts
   is  ($this, $that,    $test_name);
   isnt($this, $that,    $test_name);
 
-  # Rather than print STDERR "# here's what went wrong\n"
-  diag("here's what went wrong");
-
   like  ($this, qr/that/, $test_name);
   unlike($this, qr/that/, $test_name);
 
@@ -165,7 +167,7 @@ or for deciding between running the tests at all:
 =cut
 
 sub plan {
-    my (@plan) = @_;
+    my(@plan) = @_;
 
     my $caller = caller;
 
@@ -173,25 +175,26 @@ sub plan {
     $Test->plan(@plan);
 
     my @imports = ();
-    foreach my $idx ( 0 .. $#plan ) {
-        if ( $plan[$idx] eq 'import' ) {
-            @imports = @{ $plan[ $idx + 1 ] };
+    foreach my $idx (0..$#plan) {
+        if( $plan[$idx] eq 'import' ) {
+            @imports = @{$plan[$idx+1]};
             last;
         }
     }
 
-    __PACKAGE__->_export_to_level( 1, __PACKAGE__, @imports );
+    __PACKAGE__->_export_to_level(1, __PACKAGE__, @imports);
 }
 
 sub import {
-    my ($class) = shift;
+    my($class) = shift;
     goto &plan;
 }
 
+
 =head2 Test names
 
 By convention, each test is assigned a number in order.  This is
-largely done automatically for you.  However, it's often very useful to
+largely done automatically for you.  However, its often very useful to
 assign a name to each test.  Which would you rather see:
 
   ok 4
@@ -208,7 +211,7 @@ The later gives you some idea of what failed.  It also makes it easier
 to find the test in your script, simply search for "simple
 exponential".
 
-All test functions take a name argument.  It's optional, but highly
+All test functions take a name argument.  Its optional, but highly
 suggested that you use it.
 
 
@@ -256,8 +259,8 @@ This is actually Test::Simple's ok() routine.
 =cut
 
 sub ok ($;$) {
-    my ( $test, $name ) = @_;
-    $Test->ok( $test, $name );
+    my($test, $name) = @_;
+    $Test->ok($test, $name);
 }
 
 =item B<is>
@@ -329,6 +332,7 @@ sub isnt ($$;$) {
 
 *isn't = \&isnt;
 
+
 =item B<like>
 
   like( $this, qr/that/, $test_name );
@@ -363,6 +367,7 @@ sub like ($$;$) {
     $Test->like(@_);
 }
 
+
 =item B<unlike>
 
   unlike( $this, qr/that/, $test_name );
@@ -376,6 +381,7 @@ sub unlike {
     $Test->unlike(@_);
 }
 
+
 =item B<cmp_ok>
 
   cmp_ok( $this, $op, $that, $test_name );
@@ -402,7 +408,7 @@ and $that were:
     #         &&
     #     undef
 
-It's also useful in those cases where you are comparing numbers and
+Its also useful in those cases where you are comparing numbers and
 is()'s use of C<eq> will interfere:
 
     cmp_ok( $big_hairy_number, '==', $another_big_hairy_number );
@@ -413,6 +419,7 @@ sub cmp_ok($$$;$) {
     $Test->cmp_ok(@_);
 }
 
+
 =item B<can_ok>
 
   can_ok($module, @methods);
@@ -443,32 +450,28 @@ as one test.  If you desire otherwise, use:
 =cut
 
 sub can_ok ($@) {
-    my ( $proto, @methods ) = @_;
-    my $class = ref $proto || $proto;
+    my($proto, @methods) = @_;
+    my $class= ref $proto || $proto;
 
-    unless (@methods) {
+    unless( @methods ) {
         my $ok = $Test->ok( 0, "$class->can(...)" );
-        $Test->diag('    can_ok() called with no methods');
+        $Test->diag('can_ok() called with no methods');
         return $ok;
     }
 
     my @nok = ();
     foreach my $method (@methods) {
         my $test = "'$class'->can('$method')";
-        local ( $!, $@ );    # don't interfere with caller's $@
-                             # eval sometimes resets $!
         eval $test || push @nok, $method;
     }
 
     my $name;
-    $name =
-      @methods == 1
-      ? "$class->can('$methods[0]')"
-      : "$class->can(...)";
-
+    $name = @methods == 1 ? "$class->can($methods[0])" 
+                          : "$class->can(...)";
+    
     my $ok = $Test->ok( !@nok, $name );
 
-    $Test->diag( map "    $class->can('$_') failed\n", @nok );
+    $Test->diag(map "$class->can('$_') failed\n", @nok);
 
     return $ok;
 }
@@ -503,30 +506,27 @@ you'd like them to be more specific, you can supply an $object_name
 =cut
 
 sub isa_ok ($$;$) {
-    my ( $object, $class, $obj_name ) = @_;
+    my($object, $class, $obj_name) = @_;
 
     my $diag;
     $obj_name = 'The object' unless defined $obj_name;
     my $name = "$obj_name isa $class";
-    if ( !defined $object ) {
+    if( !defined $object ) {
         $diag = "$obj_name isn't defined";
     }
-    elsif ( !ref $object ) {
+    elsif( !ref $object ) {
         $diag = "$obj_name isn't a reference";
     }
     else {
-
         # We can't use UNIVERSAL::isa because we want to honor isa() overrides
-        local ( $@, $! );    # eval sometimes resets $!
         my $rslt = eval { $object->isa($class) };
-        if ($@) {
-            if ( $@ =~ /^Can't call method "isa" on unblessed reference/ ) {
-                if ( !UNIVERSAL::isa( $object, $class ) ) {
+        if( $@ ) {
+            if( $@ =~ /^Can't call method "isa" on unblessed reference/ ) {
+                if( !UNIVERSAL::isa($object, $class) ) {
                     my $ref = ref $object;
-                    $diag = "$obj_name isn't a '$class' it's a '$ref'";
+                    $diag = "$obj_name isn't a '$class' its a '$ref'";
                 }
-            }
-            else {
+            } else {
                 die <<WHOA;
 WHOA! I tried to call ->isa on your object and got some weird error.
 This should never happen.  Please contact the author immediately.
@@ -535,16 +535,18 @@ $@
 WHOA
             }
         }
-        elsif ( !$rslt ) {
+        elsif( !$rslt ) {
             my $ref = ref $object;
-            $diag = "$obj_name isn't a '$class' it's a '$ref'";
+            $diag = "$obj_name isn't a '$class' its a '$ref'";
         }
     }
+            
+      
 
     my $ok;
-    if ($diag) {
+    if( $diag ) {
         $ok = $Test->ok( 0, $name );
-        $Test->diag("    $diag\n");
+        $Test->diag("$diag\n");
     }
     else {
         $ok = $Test->ok( 1, $name );
@@ -553,6 +555,7 @@ WHOA
     return $ok;
 }
 
+
 =item B<pass>
 
 =item B<fail>
@@ -571,51 +574,11 @@ Use these very, very, very sparingly.
 =cut
 
 sub pass (;$) {
-    $Test->ok( 1, @_ );
+    $Test->ok(1, @_);
 }
 
 sub fail (;$) {
-    $Test->ok( 0, @_ );
-}
-
-=back
-
-=head2 Diagnostics
-
-If you pick the right test function, you'll usually get a good idea of
-what went wrong when it failed.  But sometimes it doesn't work out
-that way.  So here we have ways for you to write your own diagnostic
-messages which are safer than just C<print STDERR>.
-
-=over 4
-
-=item B<diag>
-
-  diag(@diagnostic_message);
-
-Prints a diagnostic message which is guaranteed not to interfere with
-test output.  Handy for this sort of thing:
-
-    ok( grep(/foo/, @users), "There's a foo user" ) or
-        diag("Since there's no foo, check that /etc/bar is set up right");
-
-which would produce:
-
-    not ok 42 - There's a foo user
-    #     Failed test (foo.t at line 52)
-    # Since there's no foo, check that /etc/bar is set up right.
-
-You might remember C<ok() or diag()> with the mnemonic C<open() or
-die()>.
-
-B<NOTE> The exact formatting of the diagnostic output is still
-changing, but it is guaranteed that whatever you throw at it it won't
-interfere with the test.
-
-=cut
-
-sub diag {
-    $Test->diag(@_);
+    $Test->ok(0, @_);
 }
 
 =back
@@ -650,12 +613,11 @@ is like doing this:
 =cut
 
 sub use_ok ($;@) {
-    my ( $module, @imports ) = @_;
+    my($module, @imports) = @_;
     @imports = () unless @imports;
 
     my $pack = caller;
 
-    local ( $@, $! );    # eval sometimes interferes with $!
     eval <<USE;
 package $pack;
 require $module;
@@ -664,11 +626,11 @@ USE
 
     my $ok = $Test->ok( !$@, "use $module;" );
 
-    unless ($ok) {
+    unless( $ok ) {
         chomp $@;
         $Test->diag(<<DIAGNOSTIC);
-    Tried to use '$module'.
-    Error:  $@
+Tried to use '$module'.
+Error:  $@
 DIAGNOSTIC
 
     }
@@ -685,11 +647,10 @@ Like use_ok(), except it requires the $module.
 =cut
 
 sub require_ok ($) {
-    my ($module) = shift;
+    my($module) = shift;
 
     my $pack = caller;
 
-    local ( $!, $@ );    # eval sometimes interferes with $!
     eval <<REQUIRE;
 package $pack;
 require $module;
@@ -697,11 +658,11 @@ REQUIRE
 
     my $ok = $Test->ok( !$@, "require $module;" );
 
-    unless ($ok) {
+    unless( $ok ) {
         chomp $@;
         $Test->diag(<<DIAGNOSTIC);
-    Tried to require '$module'.
-    Error:  $@
+#     Tried to require '$module'.
+#     Error:  $@
 DIAGNOSTIC
 
     }
@@ -776,17 +737,16 @@ See L</Why are skip and todo so weird?>
 
 #'#
 sub skip {
-    my ( $why, $how_many ) = @_;
-
-    unless ( defined $how_many ) {
+    my($why, $how_many) = @_;
 
+    unless( defined $how_many ) {
         # $how_many can only be avoided when no_plan is in use.
         _carp "skip() needs to know \$how_many tests are in the block"
           unless $Test::Builder::No_Plan;
         $how_many = 1;
     }
 
-    for ( 1 .. $how_many ) {
+    for( 1..$how_many ) {
         $Test->skip($why);
     }
 
@@ -794,6 +754,7 @@ sub skip {
     last SKIP;
 }
 
+
 =item B<TODO: BLOCK>
 
     TODO: {
@@ -851,17 +812,16 @@ interpret them as passing.
 =cut
 
 sub todo_skip {
-    my ( $why, $how_many ) = @_;
-
-    unless ( defined $how_many ) {
+    my($why, $how_many) = @_;
 
+    unless( defined $how_many ) {
         # $how_many can only be avoided when no_plan is in use.
         _carp "todo_skip() needs to know \$how_many tests are in the block"
           unless $Test::Builder::No_Plan;
         $how_many = 1;
     }
 
-    for ( 1 .. $how_many ) {
+    for( 1..$how_many ) {
         $Test->todo_skip($why);
     }
 
@@ -869,6 +829,7 @@ sub todo_skip {
     last TODO;
 }
 
+
 =back
 
 =head2 Comparison functions
@@ -900,22 +861,21 @@ B<NOTE> Display of scalar refs is not quite 100%
 
 use vars qw(@Data_Stack);
 my $DNE = bless [], 'Does::Not::Exist';
-
 sub is_deeply {
-    my ( $this, $that, $name ) = @_;
+    my($this, $that, $name) = @_;
 
     my $ok;
-    if ( !ref $this || !ref $that ) {
-        $ok = $Test->is_eq( $this, $that, $name );
+    if( !ref $this || !ref $that ) {
+        $ok = $Test->is_eq($this, $that, $name);
     }
     else {
         local @Data_Stack = ();
-        if ( _deep_check( $this, $that ) ) {
-            $ok = $Test->ok( 1, $name );
+        if( _deep_check($this, $that) ) {
+            $ok = $Test->ok(1, $name);
         }
         else {
-            $ok = $Test->ok( 0, $name );
-            $ok = $Test->diag( _format_stack(@Data_Stack) );
+            $ok = $Test->ok(0, $name);
+            $ok = $Test->diag(_format_stack(@Data_Stack));
         }
     }
 
@@ -923,47 +883,46 @@ sub is_deeply {
 }
 
 sub _format_stack {
-    my (@Stack) = @_;
+    my(@Stack) = @_;
 
-    my $var       = '$FOO';
+    my $var = '$FOO';
     my $did_arrow = 0;
     foreach my $entry (@Stack) {
         my $type = $entry->{type} || '';
-        my $idx = $entry->{'idx'};
-        if ( $type eq 'HASH' ) {
+        my $idx  = $entry->{'idx'};
+        if( $type eq 'HASH' ) {
             $var .= "->" unless $did_arrow++;
             $var .= "{$idx}";
         }
-        elsif ( $type eq 'ARRAY' ) {
+        elsif( $type eq 'ARRAY' ) {
             $var .= "->" unless $did_arrow++;
             $var .= "[$idx]";
         }
-        elsif ( $type eq 'REF' ) {
+        elsif( $type eq 'REF' ) {
             $var = "\${$var}";
         }
     }
 
-    my @vals = @{ $Stack[-1]{vals} }[ 0, 1 ];
+    my @vals = @{$Stack[-1]{vals}}[0,1];
     my @vars = ();
-    ( $vars[0] = $var ) =~ s/\$FOO/     \$got/;
-    ( $vars[1] = $var ) =~ s/\$FOO/\$expected/;
+    ($vars[0] = $var) =~ s/\$FOO/     \$got/;
+    ($vars[1] = $var) =~ s/\$FOO/\$expected/;
 
     my $out = "Structures begin differing at:\n";
-    foreach my $idx ( 0 .. $#vals ) {
+    foreach my $idx (0..$#vals) {
         my $val = $vals[$idx];
-        $vals[$idx] =
-            !defined $val ? 'undef'
-          : $val eq $DNE ? "Does not exist"
-          :                "'$val'";
+        $vals[$idx] = !defined $val ? 'undef' : 
+                      $val eq $DNE  ? "Does not exist"
+                                    : "'$val'";
     }
 
     $out .= "$vars[0] = $vals[0]\n";
     $out .= "$vars[1] = $vals[1]\n";
 
-    $out =~ s/^/    /msg;
     return $out;
 }
 
+
 =item B<eq_array>
 
   eq_array(\@this, \@that);
@@ -974,19 +933,18 @@ multi-level structures are handled correctly.
 =cut
 
 #'#
-sub eq_array {
-    my ( $a1, $a2 ) = @_;
+sub eq_array  {
+    my($a1, $a2) = @_;
     return 1 if $a1 eq $a2;
 
     my $ok = 1;
     my $max = $#$a1 > $#$a2 ? $#$a1 : $#$a2;
-    for ( 0 .. $max ) {
+    for (0..$max) {
         my $e1 = $_ > $#$a1 ? $DNE : $a1->[$_];
         my $e2 = $_ > $#$a2 ? $DNE : $a2->[$_];
 
-        push @Data_Stack,
-          { type => 'ARRAY', idx => $_, vals => [ $e1, $e2 ] };
-        $ok = _deep_check( $e1, $e2 );
+        push @Data_Stack, { type => 'ARRAY', idx => $_, vals => [$e1, $e2] };
+        $ok = _deep_check($e1,$e2);
         pop @Data_Stack if $ok;
 
         last unless $ok;
@@ -995,44 +953,43 @@ sub eq_array {
 }
 
 sub _deep_check {
-    my ( $e1, $e2 ) = @_;
+    my($e1, $e2) = @_;
     my $ok = 0;
 
     my $eq;
     {
-
         # Quiet uninitialized value warnings when comparing undefs.
-        local $^W = 0;
+        local $^W = 0; 
 
-        if ( $e1 eq $e2 ) {
+        if( $e1 eq $e2 ) {
             $ok = 1;
         }
         else {
-            if (    UNIVERSAL::isa( $e1, 'ARRAY' )
-                and UNIVERSAL::isa( $e2, 'ARRAY' ) )
+            if( UNIVERSAL::isa($e1, 'ARRAY') and
+                UNIVERSAL::isa($e2, 'ARRAY') )
             {
-                $ok = eq_array( $e1, $e2 );
+                $ok = eq_array($e1, $e2);
             }
-            elsif ( UNIVERSAL::isa( $e1, 'HASH' )
-                and UNIVERSAL::isa( $e2, 'HASH' ) )
+            elsif( UNIVERSAL::isa($e1, 'HASH') and
+                   UNIVERSAL::isa($e2, 'HASH') )
             {
-                $ok = eq_hash( $e1, $e2 );
+                $ok = eq_hash($e1, $e2);
             }
-            elsif ( UNIVERSAL::isa( $e1, 'REF' )
-                and UNIVERSAL::isa( $e2, 'REF' ) )
+            elsif( UNIVERSAL::isa($e1, 'REF') and
+                   UNIVERSAL::isa($e2, 'REF') )
             {
-                push @Data_Stack, { type => 'REF', vals => [ $e1, $e2 ] };
-                $ok = _deep_check( $$e1, $$e2 );
+                push @Data_Stack, { type => 'REF', vals => [$e1, $e2] };
+                $ok = _deep_check($$e1, $$e2);
                 pop @Data_Stack if $ok;
             }
-            elsif ( UNIVERSAL::isa( $e1, 'SCALAR' )
-                and UNIVERSAL::isa( $e2, 'SCALAR' ) )
+            elsif( UNIVERSAL::isa($e1, 'SCALAR') and
+                   UNIVERSAL::isa($e2, 'SCALAR') )
             {
-                push @Data_Stack, { type => 'REF', vals => [ $e1, $e2 ] };
-                $ok = _deep_check( $$e1, $$e2 );
+                push @Data_Stack, { type => 'REF', vals => [$e1, $e2] };
+                $ok = _deep_check($$e1, $$e2);
             }
             else {
-                push @Data_Stack, { vals => [ $e1, $e2 ] };
+                push @Data_Stack, { vals => [$e1, $e2] };
                 $ok = 0;
             }
         }
@@ -1041,6 +998,7 @@ sub _deep_check {
     return $ok;
 }
 
+
 =item B<eq_hash>
 
   eq_hash(\%this, \%that);
@@ -1051,17 +1009,17 @@ is a deep check.
 =cut
 
 sub eq_hash {
-    my ( $a1, $a2 ) = @_;
+    my($a1, $a2) = @_;
     return 1 if $a1 eq $a2;
 
     my $ok = 1;
     my $bigger = keys %$a1 > keys %$a2 ? $a1 : $a2;
-    foreach my $k ( keys %$bigger ) {
+    foreach my $k (keys %$bigger) {
         my $e1 = exists $a1->{$k} ? $a1->{$k} : $DNE;
         my $e2 = exists $a2->{$k} ? $a2->{$k} : $DNE;
 
-        push @Data_Stack, { type => 'HASH', idx => $k, vals => [ $e1, $e2 ] };
-        $ok = _deep_check( $e1, $e2 );
+        push @Data_Stack, { type => 'HASH', idx => $k, vals => [$e1, $e2] };
+        $ok = _deep_check($e1, $e2);
         pop @Data_Stack if $ok;
 
         last unless $ok;
@@ -1083,14 +1041,14 @@ applies to the top level.
 # We must make sure that references are treated neutrally.  It really
 # doesn't matter how we sort them, as long as both arrays are sorted
 # with the same algorithm.
-sub _bogus_sort { local $^W = 0; ref $a ? 0 : $a cmp $b }
+sub _bogus_sort { local $^W = 0;  ref $a ? 0 : $a cmp $b }
 
-sub eq_set {
-    my ( $a1, $a2 ) = @_;
+sub eq_set  {
+    my($a1, $a2) = @_;
     return 0 unless @$a1 == @$a2;
 
     # There's faster ways to do this, but this is easiest.
-    return eq_array( [ sort _bogus_sort @$a1 ], [ sort _bogus_sort @$a2 ] );
+    return eq_array( [sort _bogus_sort @$a1], [sort _bogus_sort @$a2] );
 }
 
 =back
